notAllowedParentBinds property

bool notAllowedParentBinds
final

Prohibits taking any bind of parent modules, forcing the imports of the same in the current module to be accessed. This is the same behavior as the system. Default is false;

Implementation

final bool notAllowedParentBinds;